@@ -8,7 +8,7 @@ from dh_client.entities import Entity
 class CustomProperty(Entity):
     @staticmethod
     def create_mpc_association(
-        entity_type: str, entity_urn: str, custom_properties: dict
+        entity_type: str = None, entity_urn: str = None, custom_properties: dict = None
     ) -> Dict[str, Any]:
         """Create a custom properties MPC dictionary.
 
