@@ -54,7 +54,7 @@ class GlossaryTerm(Entity):
 
     def _create_mpc(
         self,
-        definition: str,
+        definition: str = None,
         name: str = None,
         term_source: str = "INTERNAL",
         custom_properties: dict = None,
