@@ -21,7 +21,11 @@ class User(Entity):
     """
 
     def _create_mpc(
-        self, name: str, email: str = "", display_name: str = None, active: bool = True
+        self,
+        name: str = None,
+        email: str = "",
+        display_name: str = None,
+        active: bool = True,
     ) -> List[dict]:
         """Create a user mpc dictionary.
 
